@@ -6,7 +6,8 @@ sub major_pref {
 }
 
 sub major_variants {
-    return ();
+    my ($self, $major) = @_;
+    return ($major);
 }
 
 # singular : unitName -> unitName
@@ -216,4 +217,8 @@ sub render {
     return sprintf("%.4g ",$val).$self->render_unit($name, $power);
 }
 
+sub construct {
+    return;
+}
+
 1;
